﻿using System;
using System.Windows.Forms;
using ThinkGeo.MapSuite.Core;
using ThinkGeo.MapSuite.DesktopEdition;

namespace CSharpWinformsSamples
{
    public class CreateAnInMemoryFeatureLayer : UserControl
    {
        public CreateAnInMemoryFeatureLayer()
        {
            InitializeComponent();
        }

        private void CreateAnInMemoryFeatureLayer_Load(object sender, EventArgs e)
        {
            winformsMap1.MapUnit = GeographyUnit.DecimalDegree;
            winformsMap1.CurrentExtent = new RectangleShape(0, 100, 100, 0);
            winformsMap1.BackgroundOverlay.BackgroundBrush = new GeoSolidBrush(GeoColor.StandardColors.White);

            //InMemoryFeatureLayer inMemoryLayer = new InMemoryFeatureLayer();
            //inMemoryLayer.InternalFeatures.Add("Polygon", new Feature(BaseShape.CreateShapeFromWellKnownData("POLYGON((10 60,40 70,30 85, 10 60))")));
            //inMemoryLayer.InternalFeatures.Add("Multipoint", new Feature(BaseShape.CreateShapeFromWellKnownData("MULTIPOINT(10 20, 30 20,40 20, 10 30, 30 30, 40 30)")));
            //inMemoryLayer.InternalFeatures.Add("Line", new Feature(BaseShape.CreateShapeFromWellKnownData("LINESTRING(60 60, 70 70,75 60, 80 70, 85 60,95 80)")));
            //inMemoryLayer.InternalFeatures.Add("Rectangle", new Feature(new RectangleShape(65, 30, 95, 15)));

            //inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.FillSolidBrush.Color = GeoColor.FromArgb(100, GeoColor.StandardColors.RoyalBlue);
            //inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle.OutlinePen.Color = GeoColor.StandardColors.Blue;
            //inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultLineStyle.OuterPen = new GeoPen(GeoColor.FromArgb(200, GeoColor.StandardColors.Red), 5);
            //inMemoryLayer.ZoomLevelSet.ZoomLevel01.DefaultPointStyle.SymbolPen = new GeoPen(GeoColor.FromArgb(255, GeoColor.StandardColors.Green), 8);
            //inMemoryLayer.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            //LayerOverlay staticOverlay = new LayerOverlay();
            //staticOverlay.Layers.Add("InMemoryFeatureLayer", inMemoryLayer);
            //winformsMap1.Overlays.Add(staticOverlay);

            InMemoryFeatureLayer impoint = new InMemoryFeatureLayer();
            impoint.FeatureSource.Open();
            impoint.FeatureSource.BeginTransaction();
            impoint.Columns.Add(new FeatureSourceColumn("Name"));
            impoint.ZoomLevelSet.ZoomLevel01.DefaultPointStyle = new PointStyle(PointSymbolType.Circle, new GeoSolidBrush(GeoColor.SimpleColors.Black), 3);
            impoint.ZoomLevelSet.ZoomLevel01.DefaultAreaStyle = AreaStyles.CreateSimpleAreaStyle(GeoColor.FromArgb(100, GeoColor.SimpleColors.Black), GeoColor.SimpleColors.Green);
            impoint.ZoomLevelSet.ZoomLevel01.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;
            impoint.ZoomLevelSet.ZoomLevel05.DefaultTextStyle = new TextStyle("Name", new GeoFont("Arial", 8), new GeoSolidBrush(GeoColor.SimpleColors.LightYellow));
            impoint.ZoomLevelSet.ZoomLevel05.DefaultTextStyle.XOffsetInPixel = 10;
            impoint.ZoomLevelSet.ZoomLevel05.ApplyUntilZoomLevel = ApplyUntilZoomLevel.Level20;

            Random random = new Random();
            for (int i = 0; i < 3000; i++)
            {
                double lon = winformsMap1.CurrentExtent.UpperLeftPoint.X + random.NextDouble() * winformsMap1.CurrentExtent.Width;
                double lat = winformsMap1.CurrentExtent.LowerLeftPoint.Y + random.NextDouble() * winformsMap1.CurrentExtent.Height;
                Feature fpoint = new Feature(BaseShape.CreateShapeFromWellKnownData("POINT(" + lon + " " + lat + ")"));
                fpoint.ColumnValues.Add("Name", "PointName" + i);
                impoint.InternalFeatures.Add(fpoint);

                Feature farea = new Feature(BaseShape.CreateShapeFromWellKnownData("POLYGON((10 60,40 70," + lon + " " + lat + ", 10 60))"));
                farea.ColumnValues.Add("Name", "AreaName" + i);
                impoint.InternalFeatures.Add(farea);
            }
            LayerOverlay lpoint = new LayerOverlay();
            lpoint.Layers.Add("PointLayer", impoint);
            winformsMap1.Overlays.Add("PointOverlay", lpoint);

            winformsMap1.Refresh();
        }

        private WinformsMap winformsMap1;

        #region Component Designer generated code

        private System.ComponentModel.IContainer components = null;
        /// <summary> 
        /// Clean up any resources being used.
        /// </summary>
        /// <param name="disposing">true if managed resources should be disposed; otherwise, false.</param>
        protected override void Dispose(bool disposing)
        {
            if (disposing && (components != null))
            {
                components.Dispose();
            }
            base.Dispose(disposing);
        }

        /// <summary> 
        /// Required method for Designer support - do not modify 
        /// the contents of this method with the code editor.
        /// </summary>
        private void InitializeComponent()
        {
            this.winformsMap1 = new ThinkGeo.MapSuite.DesktopEdition.WinformsMap();
            this.SuspendLayout();
            // 
            // winformsMap1
            // 
            this.winformsMap1.BackColor = System.Drawing.Color.White;
            this.winformsMap1.Dock = System.Windows.Forms.DockStyle.Fill;
            this.winformsMap1.Location = new System.Drawing.Point(0, 0);
            this.winformsMap1.Name = "winformsMap1";
            this.winformsMap1.Size = new System.Drawing.Size(740, 528);
            this.winformsMap1.TabIndex = 0;
            this.winformsMap1.Text = "winformsMap1";
            // 
            // CreateAnInMemoryFeatureLayer
            // 
            this.AutoScaleDimensions = new System.Drawing.SizeF(6F, 13F);
            this.AutoScaleMode = System.Windows.Forms.AutoScaleMode.Font;
            this.Controls.Add(this.winformsMap1);
            this.Name = "CreateAnInMemoryFeatureLayer";
            this.Size = new System.Drawing.Size(740, 528);
            this.Load += new System.EventHandler(this.CreateAnInMemoryFeatureLayer_Load);
            this.ResumeLayout(false);

        }

        #endregion
    }
}
